==> order-center-domain-2.0.9-CLOUD-TEST-20220615.030823-229-sources.jar: com/tydic/dyc/oc/model/chngorder/qrybo/UocChngOrderQryBo.java <==
package com.tydic.dyc.oc.model.chngorder.qrybo;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocChngOrderQryBo
 * 说明:变更单
 * 时间:2022-03-08 17:49
 * 作者:罗有
 **/
@Data
public class UocChngOrderQryBo implements Serializable {
	private static final long serialVersionUID = 5980326960021296095L;

	@DocField(value = "变更单id")
	private Long chngOrderId;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "业务类型 1:异常变更 2订单调价3订单取消")
	private Integer busiType;

	@DocField(value = "业务类型集合")
	private List<Integer> busiTypeList;

	@DocField(value = "变更单状态")
	private String chngOrderState;

	@DocField(value = "订单来源  1 自营单品   2 电商导入   3 协议生成    ")
	private Integer orderSource;

	@DocField(value = "租户ID")
	private String tenantId;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建时间 开始")
	private Date createTimeStart;

	@DocField(value = "创建时间 结束")
	private Date createTimeEnd;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "创建人名称")
	private String createOperName;

	@DocField(value = "创建手机号")
	private String createOperMobile;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新时间 开始")
	private Date updateTimeStart;

	@DocField(value = "更新时间 结束")
	private Date updateTimeEnd;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "更新人名称")
	private String updateOperName;

	@DocField(value = "备注")
	private String remark;

	@DocField(value = "删除标志1已删除")
	private Integer delTag;

	@DocField(value = "撤单时间")
	private Date cancelTime;

	@DocField(value = "撤单时间 开始")
	private Date cancelTimeStart;

	@DocField(value = "撤单时间 结束")
	private Date cancelTimeEnd;

	@DocField(value = "撤单工号")
	private String cancelOperId;

	@DocField(value = "撤单原因")
	private String cancelReason;

	@DocField(value = "竣工时间")
	private Date finishTime;

	@DocField(value = "竣工时间 开始")
	private Date finishTimeStart;

	@DocField(value = "竣工时间 结束")
	private Date finishTimeEnd;

	@DocField(value = "逾期时间")
	private Date expTime;

	@DocField(value = "逾期时间 开始")
	private Date expTimeStart;

	@DocField(value = "逾期时间 结束")
	private Date expTimeEnd;

	@DocField(value = "拒绝原因")
	private String rejectReason;

	@DocField(value = "扩展字段1")
	private String extField1;

	@DocField(value = "扩展字段2")
	private String extField2;

	@DocField(value = "扩展字段3")
	private String extField3;

	@DocField(value = "扩展字段4")
	private String extField4;

	@DocField(value = "扩展字段5")
	private String extField5;

	@DocField(value = "排序")
	private String orderBy;

}

==> order-center-domain-3.1.0-CLOUD-TEST-20230731.024047-76-sources.jar: com/tydic/dyc/oc/model/chngorder/qrybo/UocChngOrderQryBo.java <==
package com.tydic.dyc.oc.model.chngorder.qrybo;


import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocChngOrderQryBo
 * 说明:变更单
 * 时间:2022-03-08 17:49
 * 作者:罗有
 **/
@Data
@EqualsAndHashCode(callSuper=false)
public class UocChngOrderQryBo implements Serializable {
	private static final long serialVersionUID = 5980326960021296095L;

	//变更单id")
	private Long chngOrderId;

	//订单id")
	private Long orderId;

	//业务类型 1:异常变更 2订单调价3订单取消")
	private Integer busiType;

	//业务类型集合")
	private List<Integer> busiTypeList;

	//变更单状态")
	private String chngOrderState;

	//订单来源  1 自营单品   2 电商导入   3 协议生成    ")
	private Integer orderSource;

	//租户ID")
	private String tenantId;

	//创建时间")
	private Date createTime;

	//创建时间 开始")
	private Date createTimeStart;

	//创建时间 结束")
	private Date createTimeEnd;

	//创建工号")
	private String createOperId;

	//创建人名称")
	private String createOperName;

	//创建手机号")
	private String createOperMobile;

	//更新时间")
	private Date updateTime;

	//更新时间 开始")
	private Date updateTimeStart;

	//更新时间 结束")
	private Date updateTimeEnd;

	//更新工号")
	private String updateOperId;

	//更新人名称")
	private String updateOperName;

	//备注")
	private String remark;

	//删除标志1已删除")
	private Integer delTag;

	//撤单时间")
	private Date cancelTime;

	//撤单时间 开始")
	private Date cancelTimeStart;

	//撤单时间 结束")
	private Date cancelTimeEnd;

	//撤单工号")
	private String cancelOperId;

	//撤单原因")
	private String cancelReason;

	//竣工时间")
	private Date finishTime;

	//竣工时间 开始")
	private Date finishTimeStart;

	//竣工时间 结束")
	private Date finishTimeEnd;

	//逾期时间")
	private Date expTime;

	//逾期时间 开始")
	private Date expTimeStart;

	//逾期时间 结束")
	private Date expTimeEnd;

	//拒绝原因")
	private String rejectReason;

	//扩展字段1")
	private String extField1;

	//扩展字段2")
	private String extField2;

	//扩展字段3")
	private String extField3;

	//扩展字段4")
	private String extField4;

	//扩展字段5")
	private String extField5;

	//排序")
	private String orderBy;

}
